@@ -11,18 +11,24 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
+import warnings
+from typing import TYPE_CHECKING, Any, cast
 
-from typing import Any, TypeVar
+from selenium.common.exceptions import UnknownMethodException
 
 from appium.protocols.webdriver.can_execute_commands import CanExecuteCommands
+from appium.protocols.webdriver.can_execute_scripts import CanExecuteScripts
+from appium.protocols.webdriver.can_remember_extension_presence import CanRememberExtensionPresence
 from appium.webdriver.mobilecommand import MobileCommand as Command
 
-T = TypeVar('T', bound=CanExecuteCommands)
+if TYPE_CHECKING:
+    from appium.webdriver.webdriver import WebDriver
 
 
-class Common(CanExecuteCommands):
-    def end_test_coverage(self, intent: str, path: str) -> Any:  # TODO Check return type
+class Common(CanExecuteCommands, CanExecuteScripts, CanRememberExtensionPresence):
+    def end_test_coverage(self, intent: str, path: str) -> Any:
         """Ends the coverage collection and pull the coverage.ec file from the device.
+        deprecated:: 2.9.0
 
         Android only.
         See https://github.com/appium/appium/blob/master/docs/en/writing-running-appium/android/android-coverage.md
@@ -34,25 +40,41 @@ class Common(CanExecuteCommands):
         Returns:
             TODO
         """
-        data = {
-            'intent': intent,
-            'path': path,
-        }
-        return self.execute(Command.END_TEST_COVERAGE, data)['value']
+        warnings.warn(
+            'This API is deprecated and will be removed in future versions',
+            DeprecationWarning,
+        )
+        return self.execute(
+            Command.END_TEST_COVERAGE,
+            {
+                'intent': intent,
+                'path': path,
+            },
+        )['value']
 
-    def open_notifications(self: T) -> T:
+    def open_notifications(self) -> 'WebDriver':
         """Open notification shade in Android (API Level 18 and above)
 
         Returns:
             Union['WebDriver', 'Common']: Self instance
         """
-        self.execute(Command.OPEN_NOTIFICATIONS, {})
-        return self
+        ext_name = 'mobile: openNotifications'
+        try:
+            self.assert_extension_exists(ext_name).execute_script(ext_name)
+        except UnknownMethodException:
+            # TODO: Remove the fallback
+            self.mark_extension_absence(ext_name).execute(Command.OPEN_NOTIFICATIONS, {})
+        return cast('WebDriver', self)
 
     @property
     def current_package(self) -> str:
         """Retrieves the current package running on the device."""
-        return self.execute(Command.GET_CURRENT_PACKAGE)['value']
+        ext_name = 'mobile: getCurrentPackage'
+        try:
+            return self.assert_extension_exists(ext_name).execute_script(ext_name)
+        except UnknownMethodException:
+            # TODO: Remove the fallback
+            return self.mark_extension_absence(ext_name).execute(Command.GET_CURRENT_PACKAGE)['value']
 
     def _add_commands(self) -> None:
         # noinspection PyProtectedMember,PyUnresolvedReferences
